const express = require('express');
const path = require('path');
const webpack = require('webpack');
const webpackDevMiddleware = require('webpack-dev-middleware');
const webpackHotMiddleware = require('webpack-hot-middleware');
const serveIndex = require('serve-index');
const config = require('./config');

const empty = (req, res) => {
    res.status(200);
    res.end();
};

const start = (settings) => {
    const compiler = webpack(config(settings));

    const devMiddleware = webpackDevMiddleware(compiler, {
        index: settings.rootFile,
        publicPath: settings.baseUrl,
        stats: "errors-warnings"
    });

    const server = express();

    const index = serveIndex('.', {
        filter: (filename) => !/app\./.test(filename),
        icons: true
    });

    server.get('/favicon.ico', empty);

    server.get(/.ts$/, (req, res) => {
        const exampleUrl = req.url.replace('.ts', '.html');
        res.redirect(exampleUrl);
        res.end();
    });

    server.use('/', express.static('.'), index);

    server.use(devMiddleware);

    server.use(webpackHotMiddleware(compiler, {}));

    server.get(/.html$/, (req, res) => {
        const rootFile = devMiddleware.context.outputFileSystem.readFileSync(
            path.resolve(`${settings.rootDir}/${settings.rootFile}`)
        );

        res.write(rootFile);
        res.send();
    });

    return server;
};

module.exports = start;
