module.exports = {
    ignorePatterns: [
        // Ignore build artifacts
        '/node_modules',
        '/dist',
        '/schematics',
        '/tooling/schematics',

        // Ignore playground
        '/examples',

        // Ignore modules in docs due to broken imports
        '/docs/examples/**/app.module.ts',
        '/docs/examples/shared/main.ts',
        '/docs/examples/shared/polyfills.ts'
    ],
    overrides: [
        {
            files: [
                '*.ts'
            ],
            parser: '@typescript-eslint/parser',
            parserOptions: {
                ecmaVersion: 2020,
                sourceType: 'module',
                project: [
                    'tsconfig.json',
                    'e2e/tsconfig.json',
                    'e2e_visual/tsconfig.json',
                    'test/tsconfig.json'
                ]
            },
            extends: [
                'plugin:@angular-eslint/template/process-inline-templates'
            ],
            plugins: [
                '@angular-eslint',
                '@typescript-eslint',
                'import',
                'jest',
                'rxjs'
            ],
            rules: {
                '@angular-eslint/component-selector': [
                    'warn',
                    {
                        'type': [
                            'element',
                            'attribute'
                        ],
                        'prefix': 'kendo',
                        'style': 'kebab-case'
                    }
                ],
                '@angular-eslint/directive-selector': [
                    'warn',
                    {
                        'type': 'attribute',
                        'prefix': 'kendo',
                        'style': 'camelCase'
                    }
                ],
                '@angular-eslint/no-attribute-decorator': 'error',
                '@angular-eslint/no-forward-ref': 'off',
                '@angular-eslint/no-input-rename': 'off',
                '@angular-eslint/no-output-rename': 'off',
                '@angular-eslint/pipe-prefix': [
                    'error',
                    {
                        'prefixes': [
                            'camelCase',
                            'kendo'
                        ]
                    }
                ],
                '@angular-eslint/use-lifecycle-interface': 'off',
                '@typescript-eslint/dot-notation': 'off',
                '@typescript-eslint/explicit-member-accessibility': [
                    'off',
                    {
                        'accessibility': 'explicit'
                    }
                ],
                '@typescript-eslint/member-delimiter-style': [
                    'warn',
                    {
                        'multiline': {
                            'delimiter': 'semi',
                            'requireLast': true
                        },
                        'singleline': {
                            'delimiter': 'comma',
                            'requireLast': false
                        }
                    }
                ],
                '@typescript-eslint/no-empty-function': 'off',
                '@typescript-eslint/no-inferrable-types': 'off',
                '@typescript-eslint/no-require-imports': 'error',
                '@typescript-eslint/no-shadow': [
                    'off',
                    {
                        'hoist': 'all'
                    }
                ],
                '@typescript-eslint/no-var-requires': 'error',
                '@typescript-eslint/quotes': [
                    'off',
                    'double',
                    {
                        'avoidEscape': true
                    }
                ],
                '@typescript-eslint/semi': [
                    'error'
                ],
                'import/no-deprecated': [
                    'warn'
                ],
                'brace-style': [
                    'warn',
                    '1tbs',
                    {
                        'allowSingleLine': true
                    }
                ],
                'capitalized-comments': [
                    'off',
                    'never'
                ],
                'comma-dangle': 'error',
                'default-case': 'error',
                'dot-notation': 'off',
                'id-denylist': [
                    'error',
                    'any',
                    'Number',
                    'number',
                    'String',
                    'string',
                    'Boolean',
                    'boolean',
                    'Undefined',
                    'undefined'
                ],

                /* TODO: Enable after dropping the LTS branch for Angular 11
                 * White space changes will make merges even trickier.
                 */
                // 'indent': [
                //     'warn',
                //     4
                // ],
                'no-empty': 'error',
                'no-empty-function': 'off',
                'no-redeclare': 'error',
                'no-shadow': 'off',
                'no-unused-expressions': 'warn',
                'no-use-before-define': 'off',
                'rxjs/ban-operators': [
                    'error',
                    {
                        'combineLatest': 'Use the static combineLatest',
                        'concat': 'Use the static concat',
                        'merge': 'Use the static merge',
                        'race': 'Use the static race',
                        'zip': 'Use the static zip'
                    }
                ],
                'rxjs/no-internal': 'error',
                'rxjs/no-unsafe-takeuntil': 'error',
                'semi': 'error',

                // Jest rules
                "jest/no-disabled-tests": "off",
                "jest/no-focused-tests": "error",
                "jest/no-identical-title": "warn",
                "jest/prefer-spy-on": "warn",
                "jest/prefer-to-be": "warn",
                "jest/prefer-to-have-length": "warn",
                "jest/valid-expect": "error"
            }
        },
        {
            files: [
                '*.html'
            ],
            parser: '@angular-eslint/template-parser',
            plugins: [
                '@angular-eslint'
            ],
            extends: [
                'plugin:@angular-eslint/template/recommended'
            ],
            rules: {}
        },
        {
            files: [
                "examples/**/*.ts",
                "docs/examples/**/*.ts"
            ],
            plugins: [
                '@angular-eslint'
            ],
            extends: [
                "plugin:@typescript-eslint/recommended",
                "plugin:@angular-eslint/recommended",
                "plugin:@angular-eslint/template/process-inline-templates"
            ],
            parserOptions: {
                project: [
                    "examples/tsconfig.json",
                    "docs/examples/tsconfig.json"
                ]
            },
            rules: {
                "@angular-eslint/directive-selector": "off",
                "@angular-eslint/component-selector": "off",
                "jest/no-focused-tests": "off"
            }
        }
    ]
};
