const typescriptTasks = require('@progress/kendo-typescript-tasks');
const registerPackageMetadataTasks = require('@progress/kendo-common-tasks/tasks/package-metadata');
const jest = require('gulp-jest').default;

const startServer = require('./dev-server/start');
const ngcPath = require.resolve('@angular/compiler-cli');
const addBuildBundlesTask = require( './tasks/build-bundles' );
const addBuildSchematicsTask = require( './tasks/build-schematics' );

const addTasks = (gulp, libraryName, options) => {
    const series = gulp.series;

    typescriptTasks(gulp, libraryName, ngcPath, options);

    registerPackageMetadataTasks(gulp, process.cwd(), {
        productName: 'Kendo UI for Angular',
        productCodes: [ 'KENDOUIANGULAR', 'KENDOUICOMPLETE' ],
        licensingDocsUrl: 'https://www.telerik.com/kendo-angular-ui/my-license/?utm_medium=product&utm_source=kendoangular&utm_campaign=kendo-ui-angular-purchase-license-keys-warning'
    });

    addBuildBundlesTask(gulp, libraryName);
    addBuildSchematicsTask(gulp, libraryName);

    gulp.task('test:watch', () => gulp
        .watch([ './test/**/*.ts' ], [ 'jest' ])
    );

    gulp.task('test', () => gulp
        .src([ './test/**/*.ts' ])
        .pipe(jest())
        .on('error', e => { throw e; })
    );

    const devServer = (defaultPort) => (done) => {
        const port = process.env.PORT || defaultPort;
        const root = 'examples';
        const baseUrl = `/${root}`;
        const settings = {
            baseUrl,
            rootDir: `./${root}`,
            rootFile: 'app.html',
            entry: 'app.ts',
            libraryName
        };

        const app = startServer(settings);
        app.set('port', port);
        app.listen(port, () => {
            console.info(`Development server listening on http://localhost:${port}${baseUrl}`);
        });

        process.on('exit', done);
    };

    gulp.task('start', devServer(3000));

    gulp.task('build-package', series(
        'update-package-metadata',
        'build-schematics',
        'build-bundles',
        'reset-package-metadata'
    ));
};

module.exports = addTasks;
