'use strict';

const path = require('path');
const generateNotes = require('@progress/semantic-prerelease/generateNotes');

function processNotes(pluginConfig, { pkg }, callback) {

    function changeLogDecorator() {
        let log = arguments[1];
        log = addThemesSection(log);
        log = stripPrRefs(log);
        arguments[1] = log;
        callback(...arguments);
    }

    function addThemesSection() {
        let log = arguments[0];
        const packageJsonPath = path.join(process.cwd(), '..', 'package.json'); // script is running from 'dist'
        const packageJson = require(packageJsonPath);
        const devDeps = packageJson.devDependencies;
        let themesSection = "";

        for (const pack in devDeps) {
            if (pack.match(/@progress\/kendo-theme-/)) {
                themesSection += `* ${pack}: ${devDeps[pack]}\n`;
            }
        }

        if (themesSection.length) {
            themesSection = "#### Supported themes\n\n" + themesSection;
            log += themesSection + "\n";
        }
        return log;
    }

    function stripPrRefs() {
        let log = arguments[0];
        log = log.replace(/ \(#\d*\)/g, '');
        log = log.replace(/\(\[.*\]\(.*\)\)/g, '');
        return log;
    }

    generateNotes(pluginConfig, { pkg }, changeLogDecorator);
}

module.exports = processNotes;

