const fs = require('fs');
const path = require('path');
const execSync = require('child_process').execSync;

const addBuildSchematicsTask = (gulp, libraryName) => {
    gulp.task('build-schematics', (done) => {
        const schematicsBasePath = 'tooling/schematics';
        const tscPath = require.resolve('typescript/bin/tsc');
        const configFile = `${schematicsBasePath}/tsconfig.json`;
        const tsConfigPath = path.join(process.cwd(), configFile);

        if (!fs.existsSync(schematicsBasePath)) {
            console.info(`No schematics found for ${libraryName} package`);
            done();
            return;
        }

        execSync(`${tscPath} -p ${tsConfigPath}`);

        gulp.src([
            `${schematicsBasePath}/**`,
            `!${schematicsBasePath}/**/tsconfig.json`,
            `!${schematicsBasePath}/@(*)/*.ts` //skip ts files only for the rules
        ])
            .pipe(
                gulp.dest('schematics')
            );

        done();
    });
};

module.exports = addBuildSchematicsTask;
